@@ -32,6 +32,12 @@ macro_rules! impl_uint_codec {
 				<[u8; $len * 8] as $crate::codec::Decode>::decode(input).map(|b| $name::from_little_endian(&b))
 			}
 		}
+
+		impl $crate::codec::MaxEncodedLen for $name {
+			fn max_encoded_len() -> usize {
+				::core::mem::size_of::<$name>()
+			}
+		}
 	};
 }
 
@@ -52,5 +58,11 @@ macro_rules! impl_fixed_hash_codec {
 				<[u8; $len] as $crate::codec::Decode>::decode(input).map($name)
 			}
 		}
+
+		impl $crate::codec::MaxEncodedLen for $name {
+			fn max_encoded_len() -> usize {
+				::core::mem::size_of::<$name>()
+			}
+		}
 	};
 }
